from .teomim import teomim


"""                                                                                                                        
# teomim                                                                                                                   
                                                                                                                           
Description:                                                                                                               
    Digital twin for human disease risk. Generate realistic diagnostic histories for ptients nearly indistinguishable from real population using deep comorbidity signatures.                                                                  
                                                                                                                           
---                                                                                                                        
                                                                                                                           
Installation:                                                                                                              
   ```                                                                                                                     
      pip install teomim                                                                                                   
   ```                                                                                                                                                                                                      
Notes:                                                                                                                     
   Models are contextual

"""
